Datix.ValidationError exception (datix v0.3.3)
View SourceAn exception for when a date or time fails validation.
An "invalid" date or time is a date or time that gets parsed correctly,
but that is semantically invalid. For example, a date with a day of 99
is invalid.